pub struct ContextReference {
pub kind: ContextReferenceKind,
pub source: ContextReferenceSource,
pub badge: String,
pub label: String,
pub target: String,
pub included: bool,
pub expanded: bool,
pub detail: Option<String>,
}Expand description
Durable, compact metadata for a user-visible context reference.
Fields
kind: ContextReferenceKindsource: ContextReferenceSourcebadge: StringShort badge for terminal display, e.g. file, dir, image.
label: StringCompact display label from the transcript, without the leading @.
target: StringResolved target path or URI-equivalent string.
included: boolexpanded: booldetail: Option<String>Trait Implementations
Sourceimpl Clone for ContextReference
impl Clone for ContextReference
Sourcefn clone(&self) -> ContextReference
fn clone(&self) -> ContextReference
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ContextReference
impl Debug for ContextReference
Sourceimpl<'de> Deserialize<'de> for ContextReference
impl<'de> Deserialize<'de> for ContextReference
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<ContextReference, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<ContextReference, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ContextReference
Sourceimpl PartialEq for ContextReference
impl PartialEq for ContextReference
Sourcefn eq(&self, other: &ContextReference) -> bool
fn eq(&self, other: &ContextReference) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for ContextReference
impl Serialize for ContextReference
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl StructuralPartialEq for ContextReference