pub fn format_cost_amount(cost: f64, currency: CostCurrency) -> StringExpand description
Format a cost amount for compact display in the chosen currency.
pub fn format_cost_amount(cost: f64, currency: CostCurrency) -> StringFormat a cost amount for compact display in the chosen currency.