pub fn format_cost_amount_precise(cost: f64, currency: CostCurrency) -> StringExpand description
Format a cost amount for detailed reports in the chosen currency.
pub fn format_cost_amount_precise(cost: f64, currency: CostCurrency) -> StringFormat a cost amount for detailed reports in the chosen currency.